==> gtk-gnutella-0.96.1.tar.bz2: gtk-gnutella-0.96.1/src/lib/watcher.h <==
/*
 * $Id: watcher.h,v 1.2 2005/06/25 01:37:43 daichik Exp $
 *
 * Copyright (c) 2004, Raphael Manfredi
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

/**
 * @ingroup lib
 * @file
 *
 * File watcher.
 *
 * @author Raphael Manfredi
 * @date 2004
 */

#ifndef _watcher_h_
#define _watcher_h_

#include <glib.h>

#include "file.h"

/**
 * The callback invoked when a monitored file changes.
 */
typedef void (*watcher_cb_t)(const gchar *filename, gpointer udata);

/*
 * Public interface.
 */

void watcher_init(void);
void watcher_close(void);
void watcher_register(const gchar *filename, watcher_cb_t cb, gpointer udata);
void watcher_unregister(const gchar *filename);
void watcher_register_path(
	const file_path_t *fp, watcher_cb_t cb, gpointer udata);
void watcher_unregister_path(const file_path_t *fp);

#endif /* _watcher_h_ */

==> gtk-gnutella_0.97.orig.tar.bz2: gtk-gnutella-0.97/src/lib/watcher.h <==
/*
 * $Id: watcher.h 16103 2009-03-10 14:53:39Z rmanfredi $
 *
 * Copyright (c) 2004, Raphael Manfredi
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

/**
 * @ingroup lib
 * @file
 *
 * File watcher.
 *
 * @author Raphael Manfredi
 * @date 2004
 */

#ifndef _watcher_h_
#define _watcher_h_

#include "common.h"

#include "file.h"

/**
 * The callback invoked when a monitored file changes.
 */
typedef void (*watcher_cb_t)(const char *filename, gpointer udata);

/*
 * Public interface.
 */

void watcher_init(void);
void watcher_close(void);
void watcher_register(const char *filename, watcher_cb_t cb, gpointer udata);
void watcher_unregister(const char *filename);
void watcher_register_path(
	const file_path_t *fp, watcher_cb_t cb, gpointer udata);
void watcher_unregister_path(const file_path_t *fp);

#endif /* _watcher_h_ */
